@@ -762,6 +762,9 @@ function install_manila {
             fi
             check_nfs_kernel_service_state_ubuntu
         elif [ "$SHARE_DRIVER" == $MANILA_CONTAINER_DRIVER ]; then
+            # Remove workaround for https://launchpad.net/bugs/1876820 when
+            # container driver stops using "brctl"
+            install_package bridge-utils
             if is_ubuntu; then
                 echo "Installing docker...."
                 install_docker_ubuntu
@@ -943,6 +946,10 @@ function update_tempest {
         iniset $TEMPEST_CONFIG identity alt_password $ADMIN_PASSWORD
         iniset $TEMPEST_CONFIG identity alt_tenant_name ${ALT_TENANT_NAME:-"alt_demo"}
         iniset $TEMPEST_CONFIG identity alt_domain_name $ADMIN_DOMAIN_NAME
+
+        # Max API micro-version for tempest tests
+        iniset $TEMPEST_CONFIG share min_api_microversion 2.0
+        iniset $TEMPEST_CONFIG share max_api_microversion 2.55
     fi
 }
 
