@@ -634,8 +634,9 @@ class PowerMaxStorageConnection(driver.StorageConnection):
 
                 pool_stat = {
                     'pool_name': pool['name'],
-                    'total_capacity_gb': total_size,
-                    'free_capacity_gb': total_size - used_size,
+                    'total_capacity_gb': enas_utils.mb_to_gb(total_size),
+                    'free_capacity_gb':
+                        enas_utils.mb_to_gb(total_size - used_size),
                     'qos': False,
                     'reserved_percentage': self.reserved_percentage,
                     'snapshot_support': True,
