@@ -16,7 +16,6 @@
 from oslo_log import log
 from oslo_utils import excutils
 
-from manila.i18n import _LE
 from manila.share.drivers.netapp.dataontap.client import api as netapp_api
 from manila.share.drivers.netapp import utils as na_utils
 
@@ -30,10 +29,13 @@ class NetAppBaseClient(object):
         self.connection = netapp_api.NaServer(
             host=kwargs['hostname'],
             transport_type=kwargs['transport_type'],
+            ssl_cert_path=kwargs['ssl_cert_path'],
             port=kwargs['port'],
             username=kwargs['username'],
             password=kwargs['password'],
-            trace=kwargs.get('trace', False))
+            trace=kwargs.get('trace', False),
+            api_trace_pattern=kwargs.get('api_trace_pattern',
+                                         na_utils.API_TRACE_PATTERN))
 
     def get_ontapi_version(self, cached=True):
         """Gets the supported ontapi version."""
@@ -48,9 +50,12 @@ class NetAppBaseClient(object):
         return major, minor
 
     @na_utils.trace
-    def get_system_version(self):
+    def get_system_version(self, cached=True):
         """Gets the current Data ONTAP version."""
 
+        if cached:
+            return self.connection.get_system_version()
+
         result = self.send_request('system-get-version')
 
         version_tuple = result.get_child_by_name(
@@ -61,9 +66,9 @@ class NetAppBaseClient(object):
         version = {}
         version['version'] = result.get_child_content('version')
         version['version-tuple'] = (
-            system_version_tuple.get_child_content('generation'),
-            system_version_tuple.get_child_content('major'),
-            system_version_tuple.get_child_content('minor'))
+            int(system_version_tuple.get_child_content('generation')),
+            int(system_version_tuple.get_child_content('major')),
+            int(system_version_tuple.get_child_content('minor')))
 
         return version
 
@@ -89,7 +94,7 @@ class NetAppBaseClient(object):
             result = self.send_request('license-v2-list-info')
         except netapp_api.NaApiError:
             with excutils.save_and_reraise_exception():
-                LOG.exception(_LE("Could not get licenses list."))
+                LOG.exception("Could not get licenses list.")
 
         return sorted(
             [l.get_child_content('package').lower()
